@@ -110,6 +110,7 @@ typedef mt_off_t Qword;
 #define MAX_DATA_REQUEST         3000000
 #define BUFFERED_IO_SIZE         16348
 
+unsigned int mtools_lock_timeout=30;
 
 void serve_client(int sock, char **device_name, int n_dev, int close_stderr);
 
@@ -154,7 +155,7 @@ static void free_io_buffer(io_buffer buffer) {
 
 
 static size_t buf_read (io_buffer buf, Byte* buffer, size_t nbytes) {
-	size_t rval;
+	ssize_t rval;
 	
 	if (nbytes <= buf->in_valid) {
 		memcpy(buffer, buf->in_buffer+buf->in_start, nbytes);
@@ -323,7 +324,7 @@ static char send_packet(Packet packet, io_buffer fp)
 
 static char recv_packet(Packet packet, io_buffer fp, Dword maxlength)
 {
-	int start;
+	Dword start;
 	int l;
 	Dword length = read_dword(fp);
 #if DEBUG
@@ -725,7 +726,7 @@ static int sockethandle_now = -1;
 /*
  * Catch alarm signals and exit.
  */
-static void alarm_signal(int a)
+static void alarm_signal(int a UNUSEDP)
 {
 	if (sockethandle_now != -1) {
 		close(sockethandle_now);
@@ -824,9 +825,7 @@ int main (int argc, char** argv)
 	gid_t			run_gid = 65535;
 	char*			username = strdup("nobody");
 	int			sock;
-	int			port_is_supplied = 0;
 
-	char *server_hostname=NULL;
 	char **device_name = NULL; 
 	const char *floppy0 = "/dev/fd0";
 	int n_dev;
@@ -846,7 +845,6 @@ int main (int argc, char** argv)
 						break;
 					case 's':
 						run_as_server = 1;
-						port_is_supplied = 1;
 						bind_port = getportnum(optarg);
 						break;
 
@@ -859,7 +857,6 @@ int main (int argc, char** argv)
 					case 'b':
 						run_as_server = 1;
 						bind_ip = getipaddress(optarg);
-						server_hostname=optarg;
 						break;
 					case 'x':
 						dispName = strdup(optarg);
@@ -903,9 +900,7 @@ int main (int argc, char** argv)
 		/* try to find out port that we are connected to */
 		if(getsockname(0, (struct sockaddr*) &addr, &len) >= 0 && 
 		   len == sizeof(addr)) {
-			port_is_supplied = 1;
 			bind_port = ntohs(addr.sin_port);
-			server_hostname = strdup(inet_ntoa(addr.sin_addr));
 		}
 	}
 
@@ -1043,7 +1038,7 @@ static void send_reply64(int rval, io_buffer sock, mt_off_t len) {
 	destroyPacket(reply);
 }
 
-static void cleanup(int x) {
+static void cleanup(int x UNUSEDP) {
 	unlink(XauFileName());
 	exit(-1);
 }
@@ -1192,8 +1187,7 @@ void serve_client(int sockhandle, char **device_name, int n_dev,
 #endif
 				read_packet(parm, devFd, get_dword(parm, 0));
 				send_reply(devFd, sock, get_length(parm));
-				if(get_length(parm) >= 0)
-					send_packet(parm, sock);
+				send_packet(parm, sock);
 				break;
 			case OP_WRITE:
 #if DEBUG
